@@ -59,7 +59,7 @@ var background_page = (function () {
        loginListeners.push (sender.id);
      }
    };
-   chrome.extension.onRequestExternal.addListener (onLoginListenerRequest);
+   chrome.runtime.onMessageExternal.addListener (onLoginListenerRequest);
 
    var onLoginEvent = function (request, sender, sendResponse) {
      if (request.action == "loginEvent") {
@@ -76,7 +76,7 @@ var background_page = (function () {
        }
      }
    };
-   chrome.extension.onRequest.addListener (onLoginEvent);
+   chrome.runtime.onMessage.addListener (onLoginEvent);
 
 
    /////////////////////////////////////////////////////////
@@ -496,9 +496,9 @@ var background_page = (function () {
        callback ({error: "Invalid request method"});
        return true;
      }
-     
-     log.info ('Got request: ' + request.method + ', ' + sender.tab.id);
-     
+
+     log.info ('Got request: ' + request.method);
+
      var handler = handlers [request.method];
      
      if (handler !== undefined && typeof(handler) == 'function') {
@@ -514,7 +514,7 @@ var background_page = (function () {
 
    // Main event handler and communication link
    //   w/ content scripts
-   chrome.extension.onMessage.addListener (contentScriptsRequestHandler);
+   chrome.runtime.onMessage.addListener (contentScriptsRequestHandler);
 
 
    ///////////////////////////////////////////////
